==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/d8e/openttd_8cpp.js <==
var openttd_8cpp =
[
    [ "AfterNewGRFScan", "d3/dfb/structAfterNewGRFScan.html", "d3/dfb/structAfterNewGRFScan" ],
    [ "CallLandscapeTick", "d4/d8e/openttd_8cpp.html#acd1a5365d6fa9c477f3336d0393965fa", null ],
    [ "CallWindowGameTickEvent", "d4/d8e/openttd_8cpp.html#acd54eebb8089c126ac1f03aff16371e6", null ],
    [ "CheckCaches", "d4/d8e/openttd_8cpp.html#a32a0f4e5049c3571e551e580ef6e4d19", null ],
    [ "DoAutosave", "d4/d8e/openttd_8cpp.html#a92626514eca779f2f52f9bd640caeebd", null ],
    [ "DoPaletteAnimations", "d4/d8e/openttd_8cpp.html#aa7eeb2ba0e5517177361c20f54831e58", null ],
    [ "DoStartupNewCompany", "d4/d8e/openttd_8cpp.html#a9e83da959bac3222467b93a09ccb7449", null ],
    [ "error", "d4/d8e/openttd_8cpp.html#a5a106a953b4b8958d0059cd3e957c506", null ],
    [ "GameLoop", "d4/d8e/openttd_8cpp.html#a1ccba604c34743e18775c4c72ff36948", null ],
    [ "HandleBootstrap", "d4/d8e/openttd_8cpp.html#ad98deb947212c54c29b25ff18fb46843", null ],
    [ "HandleExitGameRequest", "d4/d8e/openttd_8cpp.html#a49f9e3875ec1b2291054ea045fde8cf6", null ],
    [ "IncreaseDate", "d4/d8e/openttd_8cpp.html#a15709ac08db381313e153035e4905ba4", null ],
    [ "LoadIntroGame", "d4/d8e/openttd_8cpp.html#aba3cba3fb9b7e0680a5690e4a099abdb", null ],
    [ "MakeNewEditorWorld", "d4/d8e/openttd_8cpp.html#a72427830f55484ec114292a37e15fae1", null ],
    [ "MakeNewEditorWorldDone", "d4/d8e/openttd_8cpp.html#a8906460d3ff5175522777b9666272bd0", null ],
    [ "MakeNewGame", "d4/d8e/openttd_8cpp.html#a10c266f10d661d53d823e693dec7e215", null ],
    [ "MakeNewGameDone", "d4/d8e/openttd_8cpp.html#aed5da773a347480e8f16255ecb319333", null ],
    [ "MakeNewgameSettingsLive", "d4/d8e/openttd_8cpp.html#aec6e1cded3220fe48e5304b900981469", null ],
    [ "MusicLoop", "d4/d8e/openttd_8cpp.html#a0098c45feb1f5f8f2fd42e5430efc499", null ],
    [ "OpenBrowser", "d4/d8e/openttd_8cpp.html#adbb2acb653df76a52b67d9c5a60d653b", null ],
    [ "openttd_main", "d4/d8e/openttd_8cpp.html#ae6cedfbbe1abfcae0d6a9532e513d847", null ],
    [ "ParseResolution", "d4/d8e/openttd_8cpp.html#a40d4a79385d17989c60b60a0f66448ce", null ],
    [ "ResetMusic", "d4/d8e/openttd_8cpp.html#a5a283f5bb0d2f19013731fc70afbaca0", null ],
    [ "SafeLoad", "d4/d8e/openttd_8cpp.html#a6831ee25dfa831de6afdebb424842ceb", null ],
    [ "ShowHelp", "d4/d8e/openttd_8cpp.html#aa108beb9968ab3252f65996fd6c336bc", null ],
    [ "ShowInfoF", "d4/d8e/openttd_8cpp.html#af8867d075e7e3ad54828ab40ca1749ed", null ],
    [ "ShowOSErrorBox", "d4/d8e/openttd_8cpp.html#a200036bd3624f24bbbd5c8f0009d3366", null ],
    [ "ShutdownGame", "d4/d8e/openttd_8cpp.html#ab264e577e512abb61b114af7f375966c", null ],
    [ "StateGameLoop", "d4/d8e/openttd_8cpp.html#a78feb405a7bae4bcd68180a0779e08b4", null ],
    [ "SwitchToMode", "d4/d8e/openttd_8cpp.html#adc874554ae96fb91249ef56dcb131ba6", null ],
    [ "usererror", "d4/d8e/openttd_8cpp.html#ae70650ae6092a33187efcd6299205ba2", null ],
    [ "WriteSavegameInfo", "d4/d8e/openttd_8cpp.html#abe37de4edd440888143ba72c43a482d2", null ],
    [ "_config_file", "d4/d8e/openttd_8cpp.html#abce6f8400df0d8a8415766218d891970", null ],
    [ "_options", "d4/d8e/openttd_8cpp.html#a2309ba66ac850b714ec4966f1ba0e08f", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/d8e/openttd_8cpp.js <==
var openttd_8cpp =
[
    [ "AfterNewGRFScan", "d3/dfb/structAfterNewGRFScan.html", "d3/dfb/structAfterNewGRFScan" ],
    [ "CallLandscapeTick", "d4/d8e/openttd_8cpp.html#acd1a5365d6fa9c477f3336d0393965fa", null ],
    [ "CallWindowGameTickEvent", "d4/d8e/openttd_8cpp.html#acd54eebb8089c126ac1f03aff16371e6", null ],
    [ "CheckCaches", "d4/d8e/openttd_8cpp.html#a32a0f4e5049c3571e551e580ef6e4d19", null ],
    [ "DoAutosave", "d4/d8e/openttd_8cpp.html#a92626514eca779f2f52f9bd640caeebd", null ],
    [ "DoPaletteAnimations", "d4/d8e/openttd_8cpp.html#aa7eeb2ba0e5517177361c20f54831e58", null ],
    [ "DoStartupNewCompany", "d4/d8e/openttd_8cpp.html#a9e83da959bac3222467b93a09ccb7449", null ],
    [ "error", "d4/d8e/openttd_8cpp.html#a5a106a953b4b8958d0059cd3e957c506", null ],
    [ "GameLoop", "d4/d8e/openttd_8cpp.html#a1ccba604c34743e18775c4c72ff36948", null ],
    [ "HandleBootstrap", "d4/d8e/openttd_8cpp.html#ad98deb947212c54c29b25ff18fb46843", null ],
    [ "HandleExitGameRequest", "d4/d8e/openttd_8cpp.html#a49f9e3875ec1b2291054ea045fde8cf6", null ],
    [ "IncreaseDate", "d4/d8e/openttd_8cpp.html#a15709ac08db381313e153035e4905ba4", null ],
    [ "LoadIntroGame", "d4/d8e/openttd_8cpp.html#aba3cba3fb9b7e0680a5690e4a099abdb", null ],
    [ "MakeNewEditorWorld", "d4/d8e/openttd_8cpp.html#a72427830f55484ec114292a37e15fae1", null ],
    [ "MakeNewEditorWorldDone", "d4/d8e/openttd_8cpp.html#a8906460d3ff5175522777b9666272bd0", null ],
    [ "MakeNewGame", "d4/d8e/openttd_8cpp.html#a10c266f10d661d53d823e693dec7e215", null ],
    [ "MakeNewGameDone", "d4/d8e/openttd_8cpp.html#aed5da773a347480e8f16255ecb319333", null ],
    [ "MakeNewgameSettingsLive", "d4/d8e/openttd_8cpp.html#aec6e1cded3220fe48e5304b900981469", null ],
    [ "MusicLoop", "d4/d8e/openttd_8cpp.html#a0098c45feb1f5f8f2fd42e5430efc499", null ],
    [ "OpenBrowser", "d4/d8e/openttd_8cpp.html#adbb2acb653df76a52b67d9c5a60d653b", null ],
    [ "openttd_main", "d4/d8e/openttd_8cpp.html#ae6cedfbbe1abfcae0d6a9532e513d847", null ],
    [ "ParseResolution", "d4/d8e/openttd_8cpp.html#a40d4a79385d17989c60b60a0f66448ce", null ],
    [ "ResetMusic", "d4/d8e/openttd_8cpp.html#a5a283f5bb0d2f19013731fc70afbaca0", null ],
    [ "SafeLoad", "d4/d8e/openttd_8cpp.html#ae783c51f86a08a8fff2fc2b342082562", null ],
    [ "ShowHelp", "d4/d8e/openttd_8cpp.html#aa108beb9968ab3252f65996fd6c336bc", null ],
    [ "ShowInfoF", "d4/d8e/openttd_8cpp.html#af8867d075e7e3ad54828ab40ca1749ed", null ],
    [ "ShowOSErrorBox", "d4/d8e/openttd_8cpp.html#a200036bd3624f24bbbd5c8f0009d3366", null ],
    [ "ShutdownGame", "d4/d8e/openttd_8cpp.html#ab264e577e512abb61b114af7f375966c", null ],
    [ "StateGameLoop", "d4/d8e/openttd_8cpp.html#a78feb405a7bae4bcd68180a0779e08b4", null ],
    [ "SwitchToMode", "d4/d8e/openttd_8cpp.html#adc874554ae96fb91249ef56dcb131ba6", null ],
    [ "usererror", "d4/d8e/openttd_8cpp.html#ae70650ae6092a33187efcd6299205ba2", null ],
    [ "WriteSavegameInfo", "d4/d8e/openttd_8cpp.html#abe37de4edd440888143ba72c43a482d2", null ],
    [ "_config_file", "d4/d8e/openttd_8cpp.html#ad24b90719b1d40843c682f9b7a778f97", null ],
    [ "_options", "d4/d8e/openttd_8cpp.html#a2309ba66ac850b714ec4966f1ba0e08f", null ],
    [ "_save_config", "d4/d8e/openttd_8cpp.html#a6b31e7f0f606cf97512e4a09d1b9f4f9", null ]
];
